@@ -1,16 +1,18 @@
 from typing import Any, Type, cast
 from eth_typing import Address
-from web3client.Erc20Web3Client import Erc20Web3Client
-from web3client.Web3Client import Web3Client
+from web3client.erc20_client import Erc20Client
+from web3client.base_client import BaseClient
+from web3factory.erc20_tokens import get_token_config
 from web3factory.networks import get_network_config, pick_rpc
+from web3factory.types import NetworkName, TokenName
 
 
 def make_client(
-    networkName: str,
+    networkName: NetworkName,
     nodeUri: str = None,
-    base: Type[Web3Client] = Web3Client,
+    base: Type[BaseClient] = BaseClient,
     **clientArgs: Any
-) -> Web3Client:
+) -> BaseClient:
     """
     Return a brand new client configured for the given blockchain
     """
@@ -26,17 +28,17 @@ def make_client(
 
 
 def make_erc20_client(
-    networkName: str, nodeUri: str, tokenAddress: Address, **clientArgs: Any
-) -> Erc20Web3Client:
+    tokenName: TokenName,
+    networkName: NetworkName,
+    nodeUri: str = None,
+    **clientArgs: Any
+) -> Erc20Client:
     """
     Return a brand new client configured for the given blockchain
     and preloaded with the ERC20 token ABI
     """
+    token_address = get_token_config(tokenName, networkName)["address"]
     client = make_client(
-        networkName,
-        nodeUri,
-        Erc20Web3Client,
-        contractAddress=tokenAddress,
-        **clientArgs
+        networkName, nodeUri, Erc20Client, contractAddress=token_address, **clientArgs
     )
-    return cast(Erc20Web3Client, client)
+    return cast(Erc20Client, client)
